Subject: [bug#58488] [PATCH] gnu: gnome: Include aarch64 in librsvg-for-system.

From: Christopher Baines <[email-masked]>
Date: Thu, 13 Oct 2022 11:20:48 +0100

Since the staging merge, librsvg has been buildable for aarch64.

* gnu/packages/gnome.scm (librsvg-for-system): Use librsvg for aarch64.
---
 gnu/packages/gnome.scm | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/gnome.scm b/gnu/packages/gnome.scm
index 09a991b14c..ff9d95c244 100644
--- a/gnu/packages/gnome.scm
+++ b/gnu/packages/gnome.scm
@@ -3753,8 +3753,10 @@ (define* (librsvg-for-system #:optional
                              (system (or (%current-target-system)
                                          (%current-system))))
   ;; Since librsvg 2.50 depends on Rust, and Rust is only correctly supported
-  ;; on x86_64 so far, use the ancient C version on other platforms (FIXME).
-  (if (string-prefix? "x86_64-" system)
+  ;; on x86_64 and aarch64 so far, use the ancient C version on other
+  ;; platforms (FIXME).
+  (if (or (string-prefix? "x86_64-" system)
+          (string-prefix? "aarch64-" system))
       librsvg
       librsvg-2.40))
 
-- 
2.37.3